@@ -1,5 +1,6 @@
 import json
 from snappi_trex.info import Info
+from snappi_trex.util import Util
 
 class Metrics(object):
 
@@ -12,7 +13,7 @@ class Metrics(object):
         mc = Info.get_metrics_columns()
 
         ports = list(range(len(port_ids)))
-        if req['port']['port_names'] is not None and len(req['port']['port_names']) > 0:
+        if Util.list_not_empty('port_names', req['port']):
             ports = []
             for p_name in req['port']['port_names']:
                 ports.append(port_ids.index(p_name))
@@ -20,7 +21,7 @@ class Metrics(object):
         col_names = ['link', 'capture', 'frames_tx', 'frames_rx',
                     'bytes_tx', 'bytes_rx', 'frames_tx_rate', 'frames_rx_rate', 
                     'bytes_tx_rate', 'bytes_rx_rate']
-        if req['port']['column_names'] is not None and len(req['port']['column_names']) > 0:
+        if request.port.column_names is not None and len(req['port']['column_names']) > 0:
             col_names = req['port']['column_names']
 
         metrics = self._client.get_stats(ports=ports)
