@@ -185,3 +185,40 @@ class SetConfig:
         pad = max(0, max_pkt_size - len(pkt_base)) * '\0'
 
         return vm_cmds, pad
+
+
+    def fix_checksum(layers):
+        vm_cmds = []
+
+        # Fix all IP and checksums
+        layers_with_cs = {'IP': 0, 'UDP': 0, 'TCP': 0, 'IPv6': 0}
+        for layer in layers:
+            if layer == 'IP':
+                vm_cmds.append(STLVmFixIpv4('IP:{}'.format(layers_with_cs['IP'])))
+            if layer in layers_with_cs:
+                layers_with_cs[layer] += 1
+
+        # Fix UDP and TCP checksums in reverse
+        for i, layer in reversed(list(enumerate(layers))):
+            if i == 0:
+                continue
+
+            # Only fix the ones that sit on top of valid l3 protocols
+            if layers[i-1] == 'IP' or layers[i-1] == 'IPv6':
+                if layer == 'UDP':
+                    vm_cmds.append(STLVmFixChecksumHw(
+                        l3_offset = layers[i-1] + ':' + str(layers_with_cs[layers[i-1]] - 1),
+                        l4_offset = layer + ':' + str(layers_with_cs[layer] - 1),
+                        l4_type = CTRexVmInsFixHwCs.L4_TYPE_UDP
+                    ))
+                if layer == 'TCP':
+                    vm_cmds.append(STLVmFixChecksumHw(
+                        l3_offset = layers[i-1] + ':' + str(layers_with_cs[layers[i-1]] - 1),
+                        l4_offset = layer + ':' + str(layers_with_cs[layer] - 1),
+                        l4_type = CTRexVmInsFixHwCs.L4_TYPE_TCP
+                    ))
+
+            if layer in layers_with_cs:
+                layers_with_cs[layer] -= 1
+
+        return vm_cmds
\ No newline at end of file
