@@ -262,7 +262,7 @@ class Validation(object):
 
             if s['format'] != 'pcap':
                 raise SnappiTrexException('\'{}\' is not a supported capture format'.format(s['format']))
-            if s['packet_size'] is not None:
+            if 'packet_size' in s and s['packet_size'] is not None:
                 raise SnappiTrexException('maximum capture packet size options are not supported')
             if s['overwrite']:
                 raise SnappiTrexException('overwrite not supported for captures')
